@@ -28,12 +28,11 @@
 #include "gegl-plugin.h"  /* FIXME: should just be gegl.h */
 
 #include "editor.h"
+#include "editor-optype.h"
 #include "gegl-tree-editor.h"
 #include "gegl-node-editor.h"
 #include "gegl-tree-editor-action.h"
 
-
-static void           popup_properties                       (GeglNode           *node);
 static void           chain_in_operation                     (const gchar        *op_type);
 static void           menu_item_activate                     (GtkWidget          *widget,
                                                               gpointer            user_data);
@@ -59,54 +58,12 @@ static gboolean       completion_match_selected              (GtkEntryCompletion
                                                               gpointer            user_data);
 
 
-static void popup_properties (GeglNode *node)
-{
-  GtkWidget *dialog;
-  GtkWidget *vbox = gtk_vbox_new (FALSE, 0);
-
-  dialog = gtk_dialog_new_with_buttons (gegl_node_get_operation (node),
-                                        GTK_WINDOW (editor.window),
-                                        GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        GTK_STOCK_OK,
-                                        GTK_RESPONSE_NONE,
-                                        NULL);
-  gtk_container_add (GTK_CONTAINER (vbox), gegl_node_editor_new (node, FALSE));
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), vbox);
-
-  g_signal_connect_swapped (dialog,
-                            "response",
-                            G_CALLBACK (gtk_widget_destroy),
-                            dialog);
-
-  gtk_widget_show_all (dialog);
-}
-
 static void
 chain_in_operation (const gchar *op_type)
 {
-#if 0
-  g_warning ("request to chain in %s", op_type);
-  GeglNode *proxy;
-  GeglNode *iter;
-  GeglNode *new;
-
-  proxy = gegl_node_get_output_proxy (editor.gegl, "output");
-  iter = gegl_node_get_producer (proxy, "input");
-  new = gegl_node_new_child (editor.gegl, "operation", op_type, NULL);
-  if (iter)
-    {
-      gegl_node_link_many (iter, new, proxy, NULL);
-    }
-  else
-    {
-      gegl_node_link_many (new, proxy, NULL);
-    }
-  editor_refresh_structure();
-  popup_properties (new);
-#endif
-  GeglNode *new = gegl_add_sibling (op_type);
-  /*editor_refresh_structure();*/
-  popup_properties (new);
+    GtkWidget *widget = editor.structure;
+    gegl_add_sibling (op_type);
+    gtk_widget_show (widget);
 }
 
 static void
@@ -416,6 +373,8 @@ button_clicked (GtkButton * button, gpointer item)
   gtk_menu_popup (menu, NULL, NULL, gtk_option_menu_position, button, 0, 0);
 }
 
+
+
 GtkWidget *
 gegl_typeeditor_optype (GtkSizeGroup   *col1,
                         GtkSizeGroup   *col2,
@@ -437,6 +396,8 @@ gegl_typeeditor_optype (GtkSizeGroup   *col1,
 
   hbox = gtk_hbox_new (FALSE, 5);
   if (col1) label = gtk_label_new ("operation");
+    else
+  label = gtk_label_new ("add:");
   hbox2 = gtk_hbox_new (FALSE, 0);
   entry = gtk_entry_new ();
   if (!col1)
@@ -454,7 +415,7 @@ gegl_typeeditor_optype (GtkSizeGroup   *col1,
     }
   else
     {
-      current_type = g_strdup ("Enter action here");
+      current_type = g_strdup ("Type a GEGL operation, or examine to dropdown menu to the right");
     }
 
   if (label) gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -462,7 +423,7 @@ gegl_typeeditor_optype (GtkSizeGroup   *col1,
   gtk_box_pack_start (GTK_BOX (hbox2), entry, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (button), button_arrow);
-  if (label)
+  if (label && col1)
     {
       gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
       gtk_size_group_add_widget (col1, label);
