@@ -16,17 +16,27 @@
  * Copyright (C) 2003, 2004, 2006 Øyvind Kolås
  */
 
+#include "config.h"
 
-#include <gegl.h>
-#include "gegl-store.h"
+#include <stdio.h>
 #include <string.h>
+#include <gtk/gtk.h>
 
-GeglNode *gegl_children (GeglNode *item)
+#include "gegl-bin-gui-types.h"
+
+#include "gegl.h"
+
+#include "gegl-store.h"
+
+
+GeglNode *
+gegl_children (GeglNode *item)
 {
   return gegl_node_get_producer (item, "aux", NULL);
 }
 
-GeglNode *gegl_next_sibling (GeglNode *item)
+GeglNode *
+gegl_next_sibling (GeglNode *item)
 {
   if (!strcmp (gegl_node_get_operation (item), "clone"))
     return NULL;
@@ -38,10 +48,10 @@ node_get_consumer (GeglNode     *node,
                    const gchar  *output_pad,
                    gchar       **input_pad_name)
 {
-  GeglNode   **nodes = NULL;
-  GeglNode    *ret=NULL;
+  GeglNode    **nodes = NULL;
+  GeglNode     *ret   = NULL;
   const gchar **pads;
-  gint       count = 0;
+  gint          count = 0;
 
   if (!node)
     return ret;
@@ -62,11 +72,12 @@ node_get_consumer (GeglNode     *node,
 }
 
 
-GeglNode *gegl_previous_sibling (GeglNode *item)
+GeglNode *
+gegl_previous_sibling (GeglNode *item)
 {
   GeglNode *node;
   gchar    *pad;
-  
+
   node = node_get_consumer (item, "output", &pad);
   if (node)
     {
@@ -80,7 +91,8 @@ GeglNode *gegl_previous_sibling (GeglNode *item)
   return node;
 }
 
-GeglNode *gegl_parent (GeglNode *item)
+GeglNode *
+gegl_parent (GeglNode *item)
 {
   GeglNode *iter = item;
 
@@ -92,20 +104,21 @@ GeglNode *gegl_parent (GeglNode *item)
     return NULL;
 
   {
-    gint n_consumers;
     GeglNode    **nodes;
     const gchar **pads;
+    gint          n_consumers;
 
     n_consumers = gegl_node_get_consumers (iter, "output", &nodes, &pads);
-    if (n_consumers >0 &&
+    if (n_consumers > 0 &&
         !strcmp (pads[0], "aux"))
       {
-        GeglNode *ret=nodes[0];
+        GeglNode *ret = nodes[0];
         g_free (nodes);
         g_free (pads);
         return ret;
       }
   }
+
   return NULL;
 }
 
@@ -336,8 +349,6 @@ prev_siblings (GeglNode *item)
   return cnt;
 }
 
-#include <stdio.h>
-
 static GtkTreePath *
 gegl_store_get_path (GtkTreeModel *tree_model, GtkTreeIter *iter)
 {
@@ -362,8 +373,6 @@ gegl_store_get_path (GtkTreeModel *tree_model, GtkTreeIter *iter)
   return path;
 }
 
-#include <string.h>
-
 static void
 gegl_store_get_value (GtkTreeModel *tree_model,
                       GtkTreeIter  *iter,
@@ -569,7 +578,7 @@ gegl_store_get_value (GtkTreeModel *tree_model,
           g_value_set_string (value, STOCK_THRESHOLD);
           return;
         }
-        free (type);
+        g_free (type);
           }
 
 /* *INDENT-ON* */
@@ -633,9 +642,9 @@ gegl_store_get_value (GtkTreeModel *tree_model,
                 }
               property = gegl_next_sibling (property);
               if (prop_name)
-                free (prop_name);
+                g_free (prop_name);
               if (prop_value)
-                free (prop_value);
+                g_free (prop_value);
             }
           g_value_set_string (value, str->str);
           g_string_free (str, TRUE);
