@@ -23,14 +23,8 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "gegl-bin-gui-types.h"
-
 #include "gegl.h"
-
 #include "gegl-view.h"
-#include "gegl-tree-editor.h"
-#include "editor.h"
-
 
 enum
 {
@@ -48,13 +42,13 @@ typedef struct _GeglViewPrivate
   gint           x;
   gint           y;
   gdouble        scale;
-  gint           screen_x;  /* coordinates of drag start */
+  gint           screen_x;    /* coordinates of drag start */
   gint           screen_y;
 
-  gint           orig_x;    /* coordinates of drag start */
+  gint           orig_x;      /* coordinates of drag start */
   gint           orig_y;
 
-  gint           start_buf_x;    /* coordinates of drag start */
+  gint           start_buf_x; /* coordinates of drag start */
   gint           start_buf_y;
 
   gint           prev_x;
@@ -317,7 +311,9 @@ button_press_event (GtkWidget      *widget,
         g_free (name);
         g_free (operation);
 #endif
+#if 0
         tree_editor_set_active (editor.tree_editor, detected);
+#endif
       }
   }
 
@@ -450,11 +446,11 @@ task_monitor (GeglView *view)
 void
 gegl_view_repaint (GeglView *view)
 {
-  GtkWidget     *widget = GTK_WIDGET (view);
-  GeglViewPrivate *priv = GEGL_VIEW_GET_PRIVATE (view);
-  GeglRectangle  roi    = { priv->x / priv->scale, priv->y / priv->scale,
-                            ceil(widget->allocation.width / priv->scale+1),
-                            ceil(widget->allocation.height / priv->scale+1) };
+  GtkWidget       *widget = GTK_WIDGET (view);
+  GeglViewPrivate *priv   = GEGL_VIEW_GET_PRIVATE (view);
+  GeglRectangle    roi    = { priv->x / priv->scale, priv->y / priv->scale,
+                              ceil(widget->allocation.width / priv->scale+1),
+                              ceil(widget->allocation.height / priv->scale+1) };
 
 #if 0
   /* forget all already queued repaints */
@@ -480,7 +476,8 @@ gegl_view_repaint (GeglView *view)
     gegl_processor_set_rectangle (priv->processor, &roi);
 }
 
-GeglProcessor *gegl_view_get_processor (GeglView *self)
+GeglProcessor *
+gegl_view_get_processor (GeglView *self)
 {
   GeglViewPrivate *priv = GEGL_VIEW_GET_PRIVATE (self);
   return priv->processor;
