@@ -31,6 +31,7 @@
 #include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
 #include "gegl-tile.h"
+#include "gegl-tile-source.h"
 
 
 G_DEFINE_TYPE (GeglTile, gegl_tile, G_TYPE_OBJECT)
@@ -105,6 +106,14 @@ set_property (GObject      *gobject,
     }
 }
 
+#include "gegl-utils.h"
+
+static void default_free (gpointer data,
+                          gpointer userdata)
+{
+  gegl_free (data);
+}
+
 static void
 dispose (GObject *object)
 {
@@ -117,7 +126,8 @@ dispose (GObject *object)
     {
       if (tile->next_shared == tile)
         { /* no clones */
-          g_free (tile->data);
+          if (tile->destroy_notify)
+            tile->destroy_notify (tile->data, tile->destroy_notify_data);
           tile->data = NULL;
         }
       else
@@ -127,6 +137,14 @@ dispose (GObject *object)
         }
     }
 
+#if ENABLE_MP
+  if (tile->mutex)
+    {
+      g_mutex_free (tile->mutex);
+      tile->mutex = NULL;
+    }
+#endif
+
   (*G_OBJECT_CLASS (parent_class)->dispose)(object);
 }
 
@@ -164,15 +182,19 @@ gegl_tile_class_init (GeglTileClass *class)
 static void
 gegl_tile_init (GeglTile *tile)
 {
-  tile->storage    = NULL;
+  tile->tile_storage    = NULL;
   tile->stored_rev = 0;
   tile->rev        = 0;
   tile->lock       = 0;
   tile->data       = NULL;
-  tile->flags      = 0;
 
   tile->next_shared = tile;
   tile->prev_shared = tile;
+
+#if ENABLE_MP
+  tile->mutex = g_mutex_new ();
+#endif
+  tile->destroy_notify = default_free;
 }
 
 GeglTile *
@@ -182,7 +204,7 @@ gegl_tile_dup (GeglTile *src)
 
   tile->rev        = 1;
   tile->stored_rev = 1;
-  tile->storage    = src->storage;
+  tile->tile_storage    = src->tile_storage;
   tile->data       = src->data;
   tile->size       = src->size;
 
@@ -199,13 +221,22 @@ gegl_tile_new (gint size)
 {
   GeglTile *tile = g_object_new (GEGL_TYPE_TILE, NULL);
 
-  tile->data       = g_malloc (size);
+  tile->data       = gegl_malloc (size);
   tile->size       = size;
   tile->stored_rev = 1;
 
   return tile;
 }
 
+static gpointer
+gegl_memdup (gpointer src, gsize size)
+{
+  gpointer ret;
+  ret = gegl_malloc (size);
+  memcpy (ret, src, size);
+  return ret;
+}
+
 static void
 gegl_tile_unclone (GeglTile *tile)
 {
@@ -214,7 +245,7 @@ gegl_tile_unclone (GeglTile *tile)
       /* the tile data is shared with other tiles,
        * create a local copy
        */
-      tile->data                     = g_memdup (tile->data, tile->size);
+      tile->data                     = gegl_memdup (tile->data, tile->size);
       tile->prev_shared->next_shared = tile->next_shared;
       tile->next_shared->prev_shared = tile->prev_shared;
       tile->prev_shared              = tile;
@@ -230,9 +261,15 @@ gegl_tile_lock (GeglTile *tile)
 {
   if (tile->lock != 0)
     {
-      g_warning ("locking a tile for the second time");
+      g_print ("hm\n");
+      g_warning ("strange tile lock count: %i", tile->lock);
     }
   total_locks++;
+
+#if ENABLE_MP
+  g_mutex_lock (tile->mutex);
+#endif
+
   tile->lock++;
   /*fprintf (stderr, "global tile locking: %i %i\n", locks, unlocks);*/
 
@@ -240,67 +277,29 @@ gegl_tile_lock (GeglTile *tile)
   /*gegl_buffer_add_dirty (tile->buffer, tile->x, tile->y);*/
 }
 
+static void
+_gegl_tile_void_pyramid (GeglTileSource *source,
+                         gint            x,
+                         gint            y,
+                         gint            z)
+{
+  if (z>10)
+    return;
+  gegl_tile_source_void (source, x, y, z);
+  _gegl_tile_void_pyramid (source, x/2, y/2, z+1);
+}
+
 static void
 gegl_tile_void_pyramid (GeglTile *tile)
 {
-  /* should, to tile->storage, request it's toplevel tile, and mark
-   * it as dirty, to force a recomputation of it's toplevel at the
-   * next subdivision request. NB: a full voiding might not be neccesary,
-   * forcing a rerender of just the dirtied part might be better, more
-   * similar to how it was done in horizon, this will only work with 4->1 px
-   * averageing.
-   */
-  gint x, y, z;
-
-  x = tile->storage_x;
-  y = tile->storage_y;
-  z = 0;/*tile->storage_z;*/
-
-  for (z = 1; z < 10; z++)
+  if (tile->tile_storage && 
+      tile->z == 0) /* we only accepting voiding the base level */
     {
-#if 0
-      gint ver = (y % 2);
-      gint hor = (x % 2);
-#endif
-      x /= 2;
-      y /= 2;
-
-      gegl_provider_message (GEGL_PROVIDER (tile->storage),
-                               GEGL_TILE_VOID,
-                               x, y, z, NULL);
-#if 0
-      /* FIXME: reenable this code */
-      if (!ver)
-        {
-          if (!hor)
-            {
-              gegl_provider_message (GEGL_PROVIDER (tile->storage),
-                                       GEGL_TILE_VOID_TL,
-                                       x, y, z, NULL);
-            }
-          else
-            {
-              gegl_provider_message (GEGL_PROVIDER (tile->storage),
-                                       GEGL_TILE_VOID_TR,
-                                       x, y, z, NULL);
-            }
-        }
-      else
-        {
-          if (!hor)
-            {
-              gegl_provider_message (GEGL_PROVIDER (tile->storage),
-                                       GEGL_TILE_VOID_BL,
-                                       x, y, z, NULL);
-            }
-          else
-            {
-              gegl_provider_message (GEGL_PROVIDER (tile->storage),
-                                       GEGL_TILE_VOID_BR,
-                                       x, y, z, NULL);
-            }
-        }
-#endif
+      _gegl_tile_void_pyramid (GEGL_TILE_SOURCE (tile->tile_storage), 
+                               tile->x/2,
+                               tile->y/2,
+                               tile->z+1);
+      return;
     }
 }
 
@@ -317,8 +316,12 @@ gegl_tile_unlock (GeglTile *tile)
       tile->z == 0)
     {
       gegl_tile_void_pyramid (tile);
-      tile->rev++;
     }
+  if (tile->lock==0)
+    tile->rev++;
+#if ENABLE_MP
+  g_mutex_unlock (tile->mutex);
+#endif
 }
 
 
@@ -332,9 +335,9 @@ void
 gegl_tile_void (GeglTile *tile)
 {
   tile->stored_rev = tile->rev;
-  /* FIXME: make sure the tile is evicted from any storage/buffer caches
-   * as well
-   */
+  tile->tile_storage = NULL;
+  if (tile->z==0)
+    gegl_tile_void_pyramid (tile);
 }
 
 void
@@ -343,7 +346,7 @@ gegl_tile_cpy (GeglTile *src,
 {
   gegl_tile_lock (dst);
 
-  g_free (dst->data);
+  gegl_free (dst->data);
   dst->data = NULL;
 
   dst->next_shared              = src->next_shared;
@@ -383,15 +386,17 @@ gegl_tile_get_data (GeglTile *tile)
 
 gboolean gegl_tile_store (GeglTile *tile)
 {
-  if (tile->storage == NULL)
+  if (gegl_tile_is_stored (tile))
+    return TRUE;
+  if (tile->tile_storage == NULL)
     return FALSE;
-  return gegl_provider_message (GEGL_PROVIDER (tile->storage),
-                                  GEGL_TILE_SET, tile->storage_x,
-                                  tile->storage_y,
-                                  tile->storage_z, tile);
+  return gegl_tile_source_set_tile (GEGL_TILE_SOURCE (tile->tile_storage),
+                                    tile->x,
+                                    tile->y,
+                                    tile->z,
+                                    tile);
 }
 
-
 /* compute the tile indice of a coordinate
  * the stride is the width/height of tiles along the axis of coordinate
  */
