@@ -29,26 +29,24 @@
 #include <gegl-plugin.h>
 
 
-GType gegl_chant_get_type ();
+GType gegl_chant_get_type (void);
 typedef struct _GeglChantO  GeglChantO;
 typedef struct _GeglChant   GeglChant;
 
 static void gegl_chant_register_type       (GTypeModule *module);
 static void gegl_chant_init_properties     (GeglChant   *self);
 static void gegl_chant_class_intern_init   (gpointer     klass);
-static gpointer chant_parent_class = NULL;
+static gpointer gegl_chant_parent_class = NULL;
 
 #define GEGL_DEFINE_DYNAMIC_OPERATION(T_P)  GEGL_DEFINE_DYNAMIC_OPERATION_EXTENDED (GEGL_CHANT_C_FILE, GeglChant, gegl_chant, T_P, 0, {})
 #define GEGL_DEFINE_DYNAMIC_OPERATION_EXTENDED(C_FILE, TypeName, type_name, TYPE_PARENT, flags, CODE) \
 static void     type_name##_init              (TypeName        *self);  \
 static void     type_name##_class_init        (TypeName##Class *klass); \
 static void     type_name##_class_finalize    (TypeName##Class *klass); \
-static gpointer type_name##_parent_class = NULL;                        \
 static GType    type_name##_type_id = 0;                                \
 static void     type_name##_class_chant_intern_init (gpointer klass)    \
   {                                                                     \
-    type_name##_parent_class = g_type_class_peek_parent (klass);        \
-    chant_parent_class = type_name##_parent_class;                      \
+    gegl_chant_parent_class = g_type_class_peek_parent (klass);         \
     type_name##_class_init ((TypeName##Class*) klass);                  \
     gegl_chant_class_intern_init (klass);                               \
   }                                                                     \
@@ -189,6 +187,22 @@ GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_COMPOSER);
 
 #endif
 
+#ifdef GEGL_CHANT_TYPE_COMPOSER3
+struct _GeglChant
+{
+  GeglOperationComposer3 parent_instance;
+  gpointer               properties;
+};
+
+typedef struct
+{
+  GeglOperationComposer3Class parent_class;
+} GeglChantClass;
+
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_COMPOSER3);
+
+#endif
+
 #ifdef GEGL_CHANT_TYPE_POINT_FILTER
 struct _GeglChant
 {
@@ -205,6 +219,38 @@ GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_FILTER);
 
 #endif
 
+
+#ifdef GEGL_CHANT_TYPE_POINT_RENDER
+struct _GeglChant
+{
+  GeglOperationPointRender parent_instance;
+  gpointer                 properties;
+};
+
+typedef struct
+{
+  GeglOperationPointRenderClass parent_class;
+} GeglChantClass;
+
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_RENDER);
+
+#endif
+
+
+#ifdef GEGL_CHANT_TYPE_TEMPORAL
+struct _GeglChant
+{
+  GeglOperationTemporal parent_instance;
+  gpointer              properties;
+};
+
+typedef struct
+{
+  GeglOperationTemporalClass parent_class;
+} GeglChantClass;
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_TEMPORAL);
+#endif
+
 #ifdef GEGL_CHANT_TYPE_AREA_FILTER
 struct _GeglChant
 {
@@ -234,6 +280,20 @@ typedef struct
 GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_COMPOSER);
 #endif
 
+#ifdef GEGL_CHANT_TYPE_POINT_COMPOSER3
+struct _GeglChant
+{
+  GeglOperationPointComposer3 parent_instance;
+  gpointer                    properties;
+};
+
+typedef struct
+{
+  GeglOperationPointComposer3Class parent_class;
+} GeglChantClass;
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_COMPOSER3);
+#endif
+
 #define GEGL_CHANT(obj)  ((GeglChant*)(obj))
 
 /* if GEGL_CHANT_CUSTOM is defined you have to provide the following
@@ -256,6 +316,10 @@ static const GeglModuleInfo modinfo =
   GEGL_MODULE_ABI_VERSION
 };
 
+/* prototypes added to silence warnings from gcc for -Wmissing-prototypes*/
+gboolean                gegl_module_register (GTypeModule *module);
+const GeglModuleInfo  * gegl_module_query    (GTypeModule *module);
+
 G_MODULE_EXPORT const GeglModuleInfo *
 gegl_module_query (GTypeModule *module)
 {
@@ -487,9 +551,13 @@ set_property (GObject      *gobject,
         {/*XXX: remove old signal */                                  \
          g_object_unref (properties->name);                           \
         }                                                             \
-      properties->name = g_value_dup_object (value);                  \
-      g_signal_connect (G_OBJECT (properties->name), "changed",       \
-       G_CALLBACK(gegl_operation_vector_prop_changed), self);         \
+      properties->name = NULL;                                        \
+      if (g_value_peek_pointer (value))                               \
+        {                                                             \
+          properties->name = g_value_dup_object (value);              \
+          g_signal_connect (G_OBJECT (properties->name), "changed",   \
+          G_CALLBACK(gegl_operation_vector_prop_changed), gobject);   \
+         }
       break; /*XXX*/
 
 #include GEGL_CHANT_C_FILE
@@ -587,7 +655,7 @@ gegl_chant_constructor (GType                  type,
 {
   GObject *obj;
 
-  obj = G_OBJECT_CLASS (chant_parent_class)->constructor (
+  obj = G_OBJECT_CLASS (gegl_chant_parent_class)->constructor (
             type, n_construct_properties, construct_properties);
 
   g_object_set_data_full (obj, "chant-data", obj, gegl_chant_destroy_notify);
