@@ -56,10 +56,12 @@ typedef struct _GeglNeedVisitor      GeglNeedVisitor;
 #ifndef __GEGL_PLUGIN_H__
 typedef struct _GeglPad              GeglPad;
 typedef struct _GeglOperation        GeglOperation;
-typedef struct _GeglNodeContext      GeglNodeContext;
+typedef struct _GeglOperationContext GeglOperationContext;
 typedef struct _GeglConnection       GeglConnection;
 #endif
 typedef struct _GeglPrepareVisitor   GeglPrepareVisitor;
+typedef struct _GeglLockVisitor      GeglLockVisitor;
+typedef struct _GeglUnlockVisitor    GeglUnlockVisitor;
 typedef struct _GeglVisitable        GeglVisitable; /* dummy typedef */
 typedef struct _GeglVisitor          GeglVisitor;
 
