@@ -15,6 +15,7 @@
  *
  * Copyright 2006 Øyvind Kolås
  */
+#include "config.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -22,17 +23,23 @@
 #include <stdio.h>
 #include <string.h>
 #include <limits.h>
+
+#include "gegl.h"
 #include "gegl-types.h"
 #include "graph/gegl-node.h"
 #include "graph/gegl-pad.h"
+#include "operation/gegl-operation.h"
 #include "property-types/gegl-color.h"
 #include "property-types/gegl-curve.h"
+#include "property-types/gegl-vector.h"
+#include "property-types/gegl-paramspecs.h"
 #include "gegl-instrument.h"
 #include "gegl-xml.h"
-#include "property-types/gegl-paramspecs.h"
-#include "operation/gegl-operation.h"
 
 #ifdef G_OS_WIN32
+#ifndef PATH_MAX
+#define PATH_MAX _MAX_PATH
+#endif
 #define realpath(a, b)    _fullpath (b, a, _MAX_PATH)
 #endif
 
@@ -57,8 +64,8 @@ struct _ParseData
                          branches */
   GeglCurve   *curve;/*< the curve whose points we are parsing */
 
-  GHashTable *ids;
-  GList      *refs;
+  GHashTable  *ids;
+  GList       *refs;
 };
 
 static const gchar *name2val (const gchar **attribute_names,
@@ -123,14 +130,15 @@ set_clone_prop_as_well:
           else if (pd->path_root)
             {
               gchar absolute_path[PATH_MAX];
-              sprintf (buf, "%s/%s", pd->path_root, param_value);
+              g_snprintf (buf, sizeof (buf),
+                          "%s/%s", pd->path_root, param_value);
               realpath (buf, absolute_path);
               gegl_node_set (new, param_name, absolute_path, NULL);
             }
           else
             {
               gchar absolute_path[PATH_MAX];
-              sprintf (buf, "./%s", param_value);
+              g_snprintf (buf, sizeof (buf), "./%s", param_value);
               realpath (buf, absolute_path);
               gegl_node_set (new, param_name, absolute_path, NULL);
             }
@@ -187,6 +195,12 @@ set_clone_prop_as_well:
 	      pd->curve = NULL;
 	    }
 	}
+      else if (paramspec->value_type == GEGL_TYPE_VECTOR)
+        {
+          GeglVector *vector = gegl_vector_new ();
+          gegl_vector_parse_svg_path (vector, param_value);
+	  gegl_node_set (new, param_name, vector, NULL);
+	}
       else
         {
           g_warning ("operation desired unknown parapspec type for %s",
@@ -202,11 +216,9 @@ static void start_element (GMarkupParseContext *context,
                            gpointer             user_data,
                            GError             **error)
 {
-  const gchar **a = attribute_names;
-  const gchar **v = attribute_values;
-  ParseData    *pd;
-
-  pd = user_data;
+  const gchar **a  = attribute_names;
+  const gchar **v  = attribute_values;
+  ParseData    *pd = user_data;
 
   if (!strcmp (element_name, "gegl") ||
       !strcmp (element_name, "image"))
@@ -327,9 +339,8 @@ static void text (GMarkupParseContext *context,
                   gpointer             user_data,
                   GError             **error)
 {
-  ParseData *pd;
+  ParseData *pd = user_data;
 
-  pd = user_data;
   if (pd->param && pd->iter && !pd->curve)
     {
       param_set (pd, pd->iter, pd->param, text);
@@ -342,9 +353,7 @@ static void end_element (GMarkupParseContext *context,
                          gpointer             user_data,
                          GError             **error)
 {
-  ParseData *pd;
-
-  pd = user_data;
+  ParseData *pd = user_data;
 
   if (!strcmp (element_name, "gegl") ||
       !strcmp (element_name, "image"))
@@ -366,7 +375,7 @@ static void end_element (GMarkupParseContext *context,
         {
           pd->iter = NULL;
         }
-      pd->parent = g_list_remove (pd->parent, pd->parent->data);
+      pd->parent = g_list_delete_link (pd->parent, pd->parent);
       pd->state  = STATE_TREE_NORMAL;
     }
   else if (!strcmp (element_name, "graph"))
@@ -400,7 +409,7 @@ static void end_element (GMarkupParseContext *context,
            !strcmp (element_name, "filter"))
     {
       pd->iter   = pd->parent->data;
-      pd->parent = g_list_remove (pd->parent, pd->parent->data);
+      pd->parent = g_list_delete_link (pd->parent, pd->parent);
       pd->state  = STATE_TREE_NORMAL;
     }
 }
@@ -412,11 +421,9 @@ static void error (GMarkupParseContext *context,
                    GError              *error,
                    gpointer             user_data)
 {
-  ParseData *pd;
-  gint       line_number;
-  gint       char_number;
+  gint  line_number;
+  gint  char_number;
 
-  pd = user_data;
   g_markup_parse_context_get_position (context, &line_number, &char_number);
   g_warning ("XML Parse error %i:%i: %s",
              line_number, char_number, error->message);
@@ -448,33 +455,26 @@ GeglNode *gegl_node_new_from_xml (const gchar *xmldata,
                                   const gchar *path_root)
 {
   glong                time = gegl_ticks ();
-  GeglNode            *ret;
-  ParseData           *pd;
+  ParseData            pd   = { 0, };
   GMarkupParseContext *context;
 
-  pd = g_new0 (ParseData, 1);
+  pd.ids       = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+  pd.refs      = NULL;
+  pd.path_root = path_root;
 
-  pd->ids = g_hash_table_new_full (g_str_hash,
-                                   g_str_equal,
-                                   g_free,
-                                   NULL);
-  pd->refs      = NULL;
-  pd->path_root = path_root;
-
-  context = g_markup_parse_context_new (&parser, 0, pd, NULL);
+  context = g_markup_parse_context_new (&parser, 0, &pd, NULL);
   g_markup_parse_context_parse (context, xmldata, strlen (xmldata), NULL);
 
   /* connect clones */
-  g_list_foreach (pd->refs, each_ref, pd);
+  g_list_foreach (pd.refs, each_ref, &pd);
 
-  ret = GEGL_NODE (pd->gegl);
-  g_free (pd);
+  g_markup_parse_context_free (context);
+  g_hash_table_destroy (pd.ids);
 
   time = gegl_ticks () - time;
   gegl_instrument ("gegl", "gegl_parse_xml", time);
 
-  g_markup_parse_context_free (context);
-  return ret;
+  return GEGL_NODE (pd.gegl);
 }
 
 GeglNode *
@@ -524,17 +524,20 @@ struct _SerializeState
   gboolean     terse;
 };
 
-static void free_clone_id (gpointer key,
-                           gpointer value,
-                           gpointer user_data)
+static void
+free_clone_id (gpointer key,
+               gpointer value,
+               gpointer user_data)
 {
   g_free (value);
 }
+
 #if 0
 
-static void tuple_old (GString     *buf,
-                       const gchar *key,
-                       const gchar *value)
+static void
+tuple_old (GString     *buf,
+           const gchar *key,
+           const gchar *value)
 {
   g_assert (key);
 
@@ -560,16 +563,18 @@ static void tuple_old (GString     *buf,
     }
 }
 
-static void encode_node_attributes_old (SerializeState *ss,
-                                        GeglNode       *node,
-                                        const gchar    *id)
+static void
+encode_node_attributes_old (SerializeState *ss,
+                            GeglNode       *node,
+                            const gchar    *id)
 {
   GParamSpec **properties;
   guint        n_properties;
   gchar       *class;
   gint         i;
 
-  properties = gegl_list_properties (gegl_node_get_operation (node), &n_properties);
+  properties = gegl_list_properties (gegl_node_get_operation (node),
+                                     &n_properties);
 
   if (!ss->terse)
     {
@@ -626,7 +631,7 @@ static void encode_node_attributes_old (SerializeState *ss,
               gint  value;
               gchar str[64];
               gegl_node_get (node, properties[i]->name, &value, NULL);
-              sprintf (str, "%i", value);
+              g_snprintf (str, sizeof (str), "%i", value);
               tuple_old (ss->buf, properties[i]->name, str);
             }
           else if (properties[i]->value_type == G_TYPE_BOOLEAN)
@@ -672,9 +677,10 @@ static void encode_node_attributes_old (SerializeState *ss,
   g_free (properties);
 }
 
-static void add_stack_old (SerializeState *ss,
-                           gint            indent,
-                           GeglNode       *head)
+static void
+add_stack_old (SerializeState *ss,
+               gint            indent,
+               GeglNode       *head)
 {
   if (GEGL_IS_NODE (head))
     {
@@ -702,7 +708,8 @@ static void add_stack_old (SerializeState *ss,
               else
                 {
                   gchar temp_id[64];
-                  sprintf (temp_id, "clone%i", ss->clone_count++);
+                  g_snprintf (temp_id, sizeof (temp_id),
+                              "clone%i", ss->clone_count++);
                   id = g_strdup (temp_id);
                   g_hash_table_insert (ss->clones, iter, (gchar *) id);
                   /* the allocation is freed by the hash table */
@@ -800,35 +807,34 @@ gchar *
 gegl_node_to_xml_old (GeglNode    *gegl,
                       const gchar *path_root)
 {
-  gchar          *ret;
-  SerializeState *ss = g_new0 (SerializeState, 1);
+  SerializeState  ss;
 
-  ss->buf       = g_string_new ("");
-  ss->clones    = g_hash_table_new (NULL, NULL);
-  ss->terse     = TRUE;
-  ss->path_root = path_root;
+  ss.buf         = g_string_new ("");
+  ss.path_root   = path_root;
+  ss.clone_count = 0;
+  ss.clones      = g_hash_table_new (NULL, NULL);
+  ss.terse       = TRUE;
 
   gegl = gegl_node_get_output_proxy (gegl, "output");
 
-  g_string_append (ss->buf, "<?xml version='1.0' encoding='UTF-8'?>\n");
-  g_string_append (ss->buf, "<gegl>\n");
+  g_string_append (ss.buf, "<?xml version='1.0' encoding='UTF-8'?>\n");
+  g_string_append (ss.buf, "<gegl>\n");
 
-  add_stack_old (ss, 2, gegl);
+  add_stack_old (&ss, 2, gegl);
 
-  g_string_append (ss->buf, "</gegl>\n");
+  g_string_append (ss.buf, "</gegl>\n");
 
-  g_hash_table_foreach (ss->clones, free_clone_id, NULL);
-  g_hash_table_destroy (ss->clones);
+  g_hash_table_foreach (ss.clones, free_clone_id, NULL);
+  g_hash_table_destroy (ss.clones);
 
-  ret = g_string_free (ss->buf, FALSE);
-  g_free (ss);
-  return ret;
+  return g_string_free (ss.buf, FALSE);
 }
 #endif
 
-static void xml_attr (GString     *buf,
-                      const gchar *key,
-                      const gchar *value)
+static void
+xml_attr (GString     *buf,
+          const gchar *key,
+          const gchar *value)
 {
   g_assert (key);
 
@@ -854,9 +860,10 @@ static void xml_attr (GString     *buf,
     }
 }
 
-static void xml_param_start (SerializeState *ss,
-			     gint            indent,
-			     const gchar    *key)
+static void
+xml_param_start (SerializeState *ss,
+                 gint            indent,
+                 const gchar    *key)
 {
   g_assert (key);
   ind; g_string_append (ss->buf, "<param name='");
@@ -864,8 +871,9 @@ static void xml_param_start (SerializeState *ss,
   g_string_append (ss->buf, "'>");
 }
 
-static void xml_param_text (SerializeState *ss,
-			    const gchar    *value)
+static void
+xml_param_text (SerializeState *ss,
+                const gchar    *value)
 {
   gchar *text;
   /*gchar *p;*/
@@ -882,21 +890,23 @@ static void xml_param_text (SerializeState *ss,
     g_string_append (ss->buf, "&#10;");
     else
     g_string_append_c (ss->buf, *p);
-    
+
     }*/
 
   g_free (text);
 }
 
-static void xml_param_end (SerializeState *ss)
+static void
+xml_param_end (SerializeState *ss)
 {
   g_string_append (ss->buf, "</param>\n");
 }
 
-static void xml_param (SerializeState *ss,
-                       gint            indent,
-                       const gchar    *key,
-                       const gchar    *value)
+static void
+xml_param (SerializeState *ss,
+           gint            indent,
+           const gchar    *key,
+           const gchar    *value)
 {
   g_assert (key);
 
@@ -908,10 +918,11 @@ static void xml_param (SerializeState *ss,
   }
 }
 
-static void xml_curve_point (SerializeState *ss,
-			     gint            indent,
-			     gfloat          x,
-			     gfloat          y)
+static void
+xml_curve_point (SerializeState *ss,
+                 gint            indent,
+                 gfloat          x,
+                 gfloat          y)
 {
   gchar str[64];
   ind; g_string_append (ss->buf, "<curve-point x='");
@@ -923,9 +934,10 @@ static void xml_curve_point (SerializeState *ss,
   g_string_append (ss->buf, "'/>\n");
 }
 
-static void xml_curve (SerializeState *ss,
-		       gint            indent,
-		       GeglCurve      *curve)
+static void
+xml_curve (SerializeState *ss,
+           gint            indent,
+           GeglCurve      *curve)
 {
   gchar str[G_ASCII_DTOSTR_BUF_SIZE];
   gdouble min_y, max_y;
@@ -950,17 +962,18 @@ static void xml_curve (SerializeState *ss,
   ind; g_string_append (ss->buf, "</curve>\n");
 }
 
-static void serialize_properties (SerializeState *ss,
-                                  gint            indent,
-                                  GeglNode       *node)
+static void
+serialize_properties (SerializeState *ss,
+                      gint            indent,
+                      GeglNode       *node)
 {
   GParamSpec **properties;
   guint        n_properties;
   gboolean     got_a_param = FALSE;
   gint         i;
 
-  properties = gegl_list_properties (gegl_node_get_operation (node), &n_properties);
-
+  properties = gegl_list_properties (gegl_node_get_operation (node),
+                                     &n_properties);
 
   for (i = 0; i < n_properties; i++)
     {
@@ -1016,7 +1029,7 @@ static void serialize_properties (SerializeState *ss,
               gint  value;
               gchar str[64];
               gegl_node_get (node, properties[i]->name, &value, NULL);
-              sprintf (str, "%i", value);
+              g_snprintf (str, sizeof (str), "%i", value);
               xml_param (ss, indent + 2, properties[i]->name, str);
             }
           else if (properties[i]->value_type == G_TYPE_BOOLEAN)
@@ -1061,6 +1074,10 @@ static void serialize_properties (SerializeState *ss,
 	      indent += 2; ind; indent -= 2; xml_param_end (ss);
 	      g_object_unref (curve);
 	    }
+	  else if (properties[i]->value_type == GEGL_TYPE_VECTOR)
+	    {
+              g_print ("serialization of GeglVector NYI\n");
+	    }
           else
             {
               g_warning ("%s: serialization of %s properties not implemented",
@@ -1076,9 +1093,10 @@ static void serialize_properties (SerializeState *ss,
   g_free (properties);
 }
 
-static void serialize_layer (SerializeState *ss,
-                             gint            indent,
-                             GeglNode       *layer)
+static void
+serialize_layer (SerializeState *ss,
+                 gint            indent,
+                 GeglNode       *layer)
 {
   gchar  *name;
   gchar  *src;
@@ -1130,9 +1148,10 @@ static void serialize_layer (SerializeState *ss,
   g_string_append (ss->buf, "/>\n");
 }
 
-static void add_stack (SerializeState *ss,
-                       gint            indent,
-                       GeglNode       *head)
+static void
+add_stack (SerializeState *ss,
+           gint            indent,
+           GeglNode       *head)
 {
   /*ind; g_string_append (ss->buf, "<stack>\n");
      indent+=2;*/
@@ -1165,7 +1184,8 @@ static void add_stack (SerializeState *ss,
               else
                 {
                   gchar temp_id[64];
-                  sprintf (temp_id, "clone%i", ss->clone_count++);
+                  g_snprintf (temp_id, sizeof (temp_id),
+                              "clone%i", ss->clone_count++);
                   id = g_strdup (temp_id);
                   g_hash_table_insert (ss->clones, iter, (gchar *) id);
                   /* the allocation is freed by the hash table */
@@ -1282,27 +1302,25 @@ gchar *
 gegl_node_to_xml (GeglNode    *gegl,
                   const gchar *path_root)
 {
-  gchar          *ret;
-  SerializeState *ss = g_new0 (SerializeState, 1);
+  SerializeState  ss;
 
-  ss->buf       = g_string_new ("");
-  ss->clones    = g_hash_table_new (NULL, NULL);
-  ss->terse     = FALSE;
-  ss->path_root = path_root;
+  ss.buf         = g_string_new ("");
+  ss.path_root   = path_root;
+  ss.clone_count = 0;
+  ss.clones      = g_hash_table_new (NULL, NULL);
+  ss.terse       = FALSE;
 
   gegl = gegl_node_get_output_proxy (gegl, "output");
 
-  g_string_append (ss->buf, "<?xml version='1.0' encoding='UTF-8'?>\n");
-  g_string_append (ss->buf, "<gegl>\n");
+  g_string_append (ss.buf, "<?xml version='1.0' encoding='UTF-8'?>\n");
+  g_string_append (ss.buf, "<gegl>\n");
 
-  add_stack (ss, 2, gegl);
+  add_stack (&ss, 2, gegl);
 
-  g_string_append (ss->buf, "</gegl>\n");
+  g_string_append (ss.buf, "</gegl>\n");
 
-  g_hash_table_foreach (ss->clones, free_clone_id, NULL);
-  g_hash_table_destroy (ss->clones);
+  g_hash_table_foreach (ss.clones, free_clone_id, NULL);
+  g_hash_table_destroy (ss.clones);
 
-  ret = g_string_free (ss->buf, FALSE);
-  g_free (ss);
-  return ret;
+  return g_string_free (ss.buf, FALSE);
 }
