@@ -49,7 +49,8 @@ enum
   PROP_0,
   PROP_OP_CLASS,
   PROP_OPERATION,
-  PROP_NAME
+  PROP_NAME,
+  PROP_DONT_CACHE
 };
 
 enum
@@ -66,6 +67,7 @@ struct _GeglNodePrivate
   GeglNode       *parent;
   gchar          *name;
   GeglProcessor  *processor;
+  GHashTable     *contexts;
 };
 
 
@@ -145,6 +147,14 @@ gegl_node_class_init (GeglNodeClass *klass)
                                                         G_PARAM_CONSTRUCT |
                                                         G_PARAM_READWRITE));
 
+  g_object_class_install_property (gobject_class, PROP_DONT_CACHE,
+                                   g_param_spec_boolean ("dont-cache",
+                                                         "Do not cache",
+                                                        "Do not cache the result of this operation, the property is inherited by children created from a node.",
+                                                        TRUE,
+                                                        G_PARAM_READWRITE));
+
+
   g_object_class_install_property (gobject_class, PROP_NAME,
                                    g_param_spec_string ("name",
                                                         "Name",
@@ -199,6 +209,7 @@ gegl_node_init (GeglNode *self)
   priv->children    = NULL;
   priv->name        = NULL;
   priv->processor   = NULL;
+  priv->contexts    = g_hash_table_new (NULL, NULL);
 }
 
 static void
@@ -269,6 +280,7 @@ finalize (GObject *gobject)
     {
       g_free (priv->name);
     }
+  g_hash_table_destroy (priv->contexts);
 
   G_OBJECT_CLASS (gegl_node_parent_class)->finalize (gobject);
 }
@@ -287,8 +299,21 @@ set_property (GObject      *gobject,
         gegl_node_set_name (node, g_value_get_string (value));
         break;
 
+      case PROP_DONT_CACHE:
+        node->dont_cache = g_value_get_boolean (value);
+        break;
+
       case PROP_OP_CLASS:
-        gegl_node_set_op_class (node, g_value_get_string (value), NULL, NULL);
+        {
+          va_list null; /* dummy to pass along, it's not used anyways since
+                         * the preceding argument is NULL, gcc might warn about
+                         * use of uninitialized variable.
+                         */
+#if defined(__GNUC__)
+          memset(&null, 0, sizeof(null));
+#endif
+          gegl_node_set_op_class (node, g_value_get_string (value), NULL, null);
+        }
         break;
 
       case PROP_OPERATION:
@@ -316,6 +341,9 @@ get_property (GObject    *gobject,
           g_value_set_string (value, GEGL_OPERATION_GET_CLASS (node->operation)->name);
         break;
 
+      case PROP_DONT_CACHE:
+        g_value_set_boolean (value, node->dont_cache);
+        break;
       case PROP_NAME:
         g_value_set_string (value, gegl_node_get_name (node));
         break;
@@ -790,17 +818,14 @@ gegl_node_blit (GeglNode            *node,
       buffer = gegl_node_apply_roi (node, "output", roi);
       if (buffer && destination_buf)
         {
-          GeglBuffer *roi_buf = gegl_buffer_create_sub_buffer (buffer, roi);
-
           if (destination_buf)
             {
-              gegl_buffer_get (roi_buf, 1.0, NULL,
-                               format, destination_buf, rowstride);
+              gegl_buffer_get (buffer, 1.0, roi, format, destination_buf, rowstride);
             }
-          g_object_unref (roi_buf);
+
           if (scale != 1.0)
             {
-              g_warning ("Scale %f!=1.0 in blit without cache", scale);
+              g_warning ("Scale %f!=1.0 in blit without cache NYI", scale);
             }
         }
 
@@ -935,7 +960,8 @@ gegl_node_set_op_class (GeglNode    *node,
         }
 
       if (node->operation &&
-          type == G_OBJECT_TYPE (node->operation))
+          type == G_OBJECT_TYPE (node->operation) &&
+          first_property)
         {
           gegl_node_set_valist (node, first_property, var_args);
           return;
@@ -1218,13 +1244,6 @@ gegl_node_get_valist (GeglNode    *self,
       GParamSpec *pspec;
       gchar      *error;
 
-      if (!strcmp (property_name, "class"))
-        {
-          g_warning ("Getting a deprecated property \"class\" "
-                     "use \"operation\" instead");
-          property_name = "operation";
-        }
-
       if (!strcmp (property_name, "operation") ||
           !strcmp (property_name, "name"))
         {
@@ -1292,14 +1311,6 @@ gegl_node_set_property (GeglNode     *self,
   g_return_if_fail (property_name != NULL);
   g_return_if_fail (value != NULL);
 
-  if (!strcmp (property_name, "class"))
-    {
-      g_warning ("Setting a deprecated property \"class\", "
-                 "use \"operation\" instead.");
-
-      g_object_set_property (G_OBJECT (self), "operation", value);
-    }
-
   if (!strcmp (property_name, "operation") ||
       !strcmp (property_name, "name"))
     {
@@ -1389,22 +1400,15 @@ gegl_node_get_operation (const GeglNode *node)
 void
 gegl_node_set_need_rect (GeglNode *node,
                          gpointer  context_id,
-                         gint      x,
-                         gint      y,
-                         gint      width,
-                         gint      height)
+                         const GeglRectangle *rect)
 {
-  GeglNodeContext *context;
+  GeglOperationContext *context;
 
   g_return_if_fail (GEGL_IS_NODE (node));
   g_return_if_fail (context_id != NULL);
 
   context = gegl_node_get_context (node, context_id);
-
-  context->need_rect.x      = x;
-  context->need_rect.y      = y;
-  context->need_rect.width  = width;
-  context->need_rect.height = height;
+  gegl_operation_context_set_need_rect (context, rect);
 }
 
 const gchar *
@@ -1469,6 +1473,7 @@ gegl_node_get_bounding_box (GeglNode *root)
   GeglVisitor  *prepare_visitor;
   GeglVisitor  *have_visitor;
   GeglVisitor  *finish_visitor;
+
   guchar       *id;
   gint          i;
 
@@ -1508,6 +1513,8 @@ gegl_node_get_bounding_box (GeglNode *root)
   return root->have_rect;
 }
 
+#if 1
+
 void
 gegl_node_process (GeglNode *self)
 {
@@ -1521,7 +1528,7 @@ gegl_node_process (GeglNode *self)
   gegl_processor_destroy (processor);
 }
 
-#if 0
+#else
 /* simplest form of GeglProcess that processes all data in one
  *
  * single large chunk
@@ -1530,7 +1537,7 @@ void
 gegl_node_process (GeglNode *self)
 {
   GeglNode        *input;
-  GeglNodeContext *context;
+  GeglOperationContext *context;
   GeglBuffer      *buffer;
   GeglRectangle    defined;
 
@@ -1549,44 +1556,33 @@ gegl_node_process (GeglNode *self)
     GValue value = { 0, };
     g_value_init (&value, GEGL_TYPE_BUFFER);
     g_value_set_object (&value, buffer);
-    gegl_node_context_set_property (context, "input", &value);
+    gegl_operation_context_set_property (context, "input", &value);
     g_value_unset (&value);
   }
 
-  gegl_node_context_set_result_rect (context, defined.x, defined.y, defined.width, defined.h);
+  gegl_operation_context_set_result_rect (context, defined.x, defined.y, defined.width, defined.h);
   gegl_operation_process (self->operation, &defined, "foo");
   gegl_node_remove_context (self, &defined);
   g_object_unref (buffer);
 }
 #endif
 
-static gint
-lookup_context (gconstpointer a,
-                gconstpointer context_id)
-{
-  GeglNodeContext *context = (void *) a;
-
-  if (context->context_id == context_id)
-    return 0;
-  return -1;
-}
-
 void babl_backtrack (void);
 
-GeglNodeContext *
+GeglOperationContext *
 gegl_node_get_context (GeglNode *self,
                        gpointer  context_id)
 {
-  GSList          *found;
-  GeglNodeContext *context = NULL;
+  GeglOperationContext *context = NULL;
+  GeglNodePrivate *priv;
 
   g_return_val_if_fail (GEGL_IS_NODE (self), NULL);
   g_return_val_if_fail (context_id != NULL, NULL);
 
-  found = g_slist_find_custom (self->context, context_id, lookup_context);
-  if (found)
-    context = found->data;
-  else
+  priv = GEGL_NODE_GET_PRIVATE (self);
+
+  context = g_hash_table_lookup (priv->contexts, context_id);
+  if (!context)
     {
       g_warning ("didn't find %p", context_id);
       babl_backtrack ();
@@ -1598,7 +1594,8 @@ void
 gegl_node_remove_context (GeglNode *self,
                           gpointer  context_id)
 {
-  GeglNodeContext *context;
+  GeglOperationContext *context;
+  GeglNodePrivate *priv;
 
   g_return_if_fail (GEGL_IS_NODE (self));
   g_return_if_fail (context_id != NULL);
@@ -1610,24 +1607,23 @@ gegl_node_remove_context (GeglNode *self,
                  context_id, gegl_node_get_debug_name (self));
       return;
     }
-  self->context = g_slist_remove (self->context, context);
+  priv = GEGL_NODE_GET_PRIVATE (self);
+  g_hash_table_remove (priv->contexts, context_id);
   g_object_unref (context);
 }
 
-GeglNodeContext *
+GeglOperationContext *
 gegl_node_add_context (GeglNode *self,
                        gpointer  context_id)
 {
-  GeglNodeContext *context = NULL;
-  GSList          *found;
+  GeglOperationContext *context = NULL;
+  GeglNodePrivate *priv;
 
   g_return_val_if_fail (GEGL_IS_NODE (self), NULL);
   g_return_val_if_fail (context_id != NULL, NULL);
 
-  found = g_slist_find_custom (self->context, context_id, lookup_context);
-
-  if (found)
-    context = found->data;
+  priv = GEGL_NODE_GET_PRIVATE (self);
+  context = g_hash_table_lookup (priv->contexts, context_id);
 
   if (context)
     {
@@ -1636,10 +1632,9 @@ gegl_node_add_context (GeglNode *self,
       return context;
     }
 
-  context             = g_object_new (GEGL_TYPE_NODE_CONTEXT, NULL);
-  context->node       = self;
-  context->context_id = context_id;
-  self->context       = g_slist_prepend (self->context, context);
+  context             = g_object_new (GEGL_TYPE_OPERATION_CONTEXT, NULL);
+  context->operation  = self->operation;
+  g_hash_table_insert (priv->contexts, context_id, context);
   return context;
 }
 
@@ -1866,6 +1861,8 @@ gegl_node_add_child (GeglNode *self,
   self->is_graph = TRUE;
   child_priv->parent  = self;
 
+  child->dont_cache = self->dont_cache;
+
   return child;
 }
 
@@ -1995,7 +1992,9 @@ gegl_node_new_child (GeglNode    *parent,
 
   node = g_object_new (GEGL_TYPE_NODE, NULL);
   if (parent)
-    gegl_node_add_child (parent, node);
+    {
+      gegl_node_add_child (parent, node);
+    }
 
   name = first_property_name;
   va_start (var_args, first_property_name);
@@ -2011,9 +2010,15 @@ GeglNode *
 gegl_node_create_child (GeglNode    *self,
                         const gchar *operation)
 {
+  GeglNode *ret;
   g_return_val_if_fail (operation != NULL, NULL);
 
-  return gegl_node_new_child (self, "operation", operation, NULL);
+  ret = gegl_node_new_child (self, "operation", operation, NULL);
+  if (ret && self)
+    {
+      ret->dont_cache = self->dont_cache;
+    }
+  return ret;
 }
 
 static void
