@@ -15,40 +15,49 @@
  *
  * Copyright 2007 Øyvind Kolås
  */
-#define GEGL_PROCESSOR_CHUNK_SIZE 256*256
 
 #include "config.h"
+
 #include <glib-object.h>
-#include "gegl-types.h"
-#include "graph/gegl-node.h"
-#include "gegl-processor.h"
-#include "gegl-utils.h"
+
 #include "buffer/gegl-region.h"
+
+#include "graph/gegl-node.h"
+
 #include "operation/gegl-operation-sink.h"
 
+#include "gegl-config.h"
+#include "gegl-processor.h"
+#include "gegl-types.h"
+#include "gegl-utils.h"
+
+
 enum
 {
   PROP_0,
   PROP_NODE,
   PROP_CHUNK_SIZE,
-  PROP_PROGRESS
+  PROP_PROGRESS,
+  PROP_RECTANGLE
 };
 
-static void gegl_processor_class_init (GeglProcessorClass *klass);
-static void gegl_processor_init       (GeglProcessor      *self);
-static void finalize                  (GObject            *self_object);
-static void set_property              (GObject            *gobject,
-                                       guint               prop_id,
-                                       const GValue       *value,
-                                       GParamSpec         *pspec);
-static void get_property              (GObject            *gobject,
-                                       guint               prop_id,
-                                       GValue             *value,
-                                       GParamSpec         *pspec);
-static GObject * constructor          (GType                  type,
-                                       guint                  n_params,
-                                       GObjectConstructParam *params);
-static gdouble   gegl_processor_progress (GeglProcessor *processor);
+
+static void      gegl_processor_class_init   (GeglProcessorClass    *klass);
+static void      gegl_processor_init         (GeglProcessor         *self);
+static void      gegl_processor_finalize     (GObject               *self_object);
+static void      gegl_processor_set_property (GObject               *gobject,
+                                              guint                  prop_id,
+                                              const GValue          *value,
+                                              GParamSpec            *pspec);
+static void      gegl_processor_get_property (GObject               *gobject,
+                                              guint                  prop_id,
+                                              GValue                *value,
+                                              GParamSpec            *pspec);
+static GObject * gegl_processor_constructor  (GType                  type,
+                                              guint                  n_params,
+                                              GObjectConstructParam *params);
+static gdouble   gegl_processor_progress     (GeglProcessor         *processor);
+
 
 struct _GeglProcessor
 {
@@ -56,49 +65,64 @@ struct _GeglProcessor
   GeglNode        *node;
   GeglRectangle    rectangle;
   GeglNode        *input;
-  GeglNodeContext *context;
+  GeglOperationContext *context;
 
-  GeglRegion *valid_region; /* used when doing unbuffered rendering */
-  GeglRegion *queued_region;
-  GSList     *dirty_rectangles;
-  gint        chunk_size;
+  GeglRegion      *valid_region;     /* used when doing unbuffered rendering */
+  GeglRegion      *queued_region;
+  GSList          *dirty_rectangles;
+  gint             chunk_size;
 
-  GThread *thread;
-  gboolean thread_done;
-  gdouble  progress;
+  GThread         *thread;
+  gboolean         thread_done;
+  gdouble          progress;
 };
 
+
 G_DEFINE_TYPE (GeglProcessor, gegl_processor, G_TYPE_OBJECT);
 
-static void gegl_processor_class_init (GeglProcessorClass *klass)
+
+static void
+gegl_processor_class_init (GeglProcessorClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  gobject_class->finalize     = finalize;
-  gobject_class->constructor  = constructor;
-  gobject_class->set_property = set_property;
-  gobject_class->get_property = get_property;
+  gobject_class->finalize     = gegl_processor_finalize;
+  gobject_class->constructor  = gegl_processor_constructor;
+  gobject_class->set_property = gegl_processor_set_property;
+  gobject_class->get_property = gegl_processor_get_property;
 
   g_object_class_install_property (gobject_class, PROP_NODE,
                                    g_param_spec_object ("node",
                                                         "GeglNode",
-                                                        "The GeglNode to process (will saturate the providers cache if it the provided node is a sink node)",
+                                                        "The GeglNode to process (will saturate the provider's cache if the provided node is a sink node)",
                                                         GEGL_TYPE_NODE,
                                                         G_PARAM_WRITABLE |
                                                         G_PARAM_CONSTRUCT));
 
+  g_object_class_install_property (gobject_class, PROP_RECTANGLE,
+                                   g_param_spec_pointer ("rectangle",
+                                                         "rectangle",
+                                                         "The rectangle of the region to process.",
+                                                         G_PARAM_READWRITE));
+
   g_object_class_install_property (gobject_class, PROP_PROGRESS,
-                                   g_param_spec_double ("progress", "progress", "query progress 0.0 is not started 1.0 is done.",
-                                                     0.0, 1.0, 0.0,
-                                                     G_PARAM_READWRITE));
+                                   g_param_spec_double ("progress",
+                                                        "progress",
+                                                        "query progress; 0.0 is not started, 1.0 is done.",
+                                                        0.0, 1.0, 0.0,
+                                                        G_PARAM_READWRITE));
+
   g_object_class_install_property (gobject_class, PROP_CHUNK_SIZE,
-                                   g_param_spec_int ("chunksize", "chunksize", "Size of chunks being rendered (larger chunks need more memory to do the processing).",
-                                                     8 * 8, 2048 * 2048, GEGL_PROCESSOR_CHUNK_SIZE,
+                                   g_param_spec_int ("chunksize",
+                                                     "chunksize",
+                                                     "Size of chunks being rendered (larger chunks need more memory to do the processing).",
+                                                     1, 1024 * 1024, gegl_config()->chunk_size, 
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
 }
 
-static void gegl_processor_init (GeglProcessor *processor)
+static void
+gegl_processor_init (GeglProcessor *processor)
 {
   processor->node             = NULL;
   processor->input            = NULL;
@@ -108,10 +132,10 @@ static void gegl_processor_init (GeglProcessor *processor)
   processor->chunk_size       = 128 * 128;
 }
 
-
-static GObject *constructor (GType                  type,
-                             guint                  n_params,
-                             GObjectConstructParam *params)
+static GObject *
+gegl_processor_constructor (GType                  type,
+                            guint                  n_params,
+                            GObjectConstructParam *params)
 {
   GObject       *object;
   GeglProcessor *processor;
@@ -125,15 +149,20 @@ static GObject *constructor (GType                  type,
     {
       processor->input = gegl_node_get_producer (processor->node, "input", NULL);
       if (!gegl_operation_sink_needs_full (processor->node->operation))
-        processor->valid_region = gegl_region_new ();
+        {
+          processor->valid_region = gegl_region_new ();
+        }
       else
-        processor->valid_region = NULL;
+        {
+          processor->valid_region = NULL;
+        }
     }
   else
     {
       processor->input = processor->node;
       processor->valid_region = NULL;
     }
+
   g_object_ref (processor->input);
 
   processor->queued_region = gegl_region_new ();
@@ -141,29 +170,39 @@ static GObject *constructor (GType                  type,
   return object;
 }
 
-
-static void finalize (GObject *self_object)
+static void
+gegl_processor_finalize (GObject *self_object)
 {
   GeglProcessor *processor = GEGL_PROCESSOR (self_object);
 
   if (processor->node)
-    g_object_unref (processor->node);
+    {
+      g_object_unref (processor->node);
+    }
+
   if (processor->input)
-    g_object_unref (processor->input);
+    {
+      g_object_unref (processor->input);
+    }
+
   if (processor->queued_region)
-    gegl_region_destroy (processor->queued_region);
+    {
+      gegl_region_destroy (processor->queued_region);
+    }
+
   if (processor->valid_region)
-    gegl_region_destroy (processor->valid_region);
+    {
+      gegl_region_destroy (processor->valid_region);
+    }
 
   G_OBJECT_CLASS (gegl_processor_parent_class)->finalize (self_object);
 }
 
-
 static void
-set_property (GObject      *gobject,
-              guint         property_id,
-              const GValue *value,
-              GParamSpec   *pspec)
+gegl_processor_set_property (GObject      *gobject,
+                             guint         property_id,
+                             const GValue *value,
+                             GParamSpec   *pspec)
 {
   GeglProcessor *self = GEGL_PROCESSOR (gobject);
 
@@ -181,6 +220,10 @@ set_property (GObject      *gobject,
         self->chunk_size = g_value_get_int (value);
         break;
 
+      case PROP_RECTANGLE:
+        gegl_processor_set_rectangle (self, g_value_get_pointer (value));
+        break;
+
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
         break;
@@ -188,10 +231,10 @@ set_property (GObject      *gobject,
 }
 
 static void
-get_property (GObject    *gobject,
-              guint       property_id,
-              GValue     *value,
-              GParamSpec *pspec)
+gegl_processor_get_property (GObject    *gobject,
+                             guint       property_id,
+                             GValue     *value,
+                             GParamSpec *pspec)
 {
   GeglProcessor *self = GEGL_PROCESSOR (gobject);
 
@@ -201,6 +244,10 @@ get_property (GObject    *gobject,
         g_value_set_object (value, self->node);
         break;
 
+      case PROP_RECTANGLE:
+        g_value_set_pointer (value, &self->rectangle);
+        break;
+
       case PROP_CHUNK_SIZE:
         g_value_set_int (value, self->chunk_size);
         break;
@@ -220,19 +267,29 @@ gegl_processor_set_rectangle (GeglProcessor       *processor,
 {
   GSList        *iter;
   GeglRectangle  bounds;
+  GeglRectangle  input_bounding_box;
 
-  if (gegl_rectangle_equal (&processor->rectangle, rectangle))
-    return;
+  if (! rectangle)
+    {
+      input_bounding_box = gegl_node_get_bounding_box (processor->input);
+      rectangle          = &input_bounding_box;
+    }
 
-  bounds               = gegl_node_get_bounding_box (processor->input);
-  processor->rectangle = *rectangle;
-  gegl_rectangle_intersect (&processor->rectangle, &processor->rectangle, &bounds);
+  if (! gegl_rectangle_equal (&processor->rectangle, rectangle))
+    {
+      bounds               = gegl_node_get_bounding_box (processor->input);
+      processor->rectangle = *rectangle;
+      gegl_rectangle_intersect (&processor->rectangle, &processor->rectangle, &bounds);
 
-  /* remove already queued dirty rectangles */
-  for (iter = processor->dirty_rectangles; iter; iter = g_slist_next (iter))
-    g_slice_free (GeglRectangle, iter->data);
-  g_slist_free (processor->dirty_rectangles);
-  processor->dirty_rectangles = NULL;
+      /* remove already queued dirty rectangles */
+      for (iter = processor->dirty_rectangles; iter; iter = g_slist_next (iter))
+        {
+          g_slice_free (GeglRectangle, iter->data);
+        }
+      g_slist_free (processor->dirty_rectangles);
+
+      processor->dirty_rectangles = NULL;
+    }
 }
 
 GeglProcessor *
@@ -243,25 +300,17 @@ gegl_node_new_processor (GeglNode            *node,
 
   g_return_val_if_fail (GEGL_IS_NODE (node), NULL);
 
-  processor = g_object_new (GEGL_TYPE_PROCESSOR, "node", node, NULL);
+  processor = g_object_new (GEGL_TYPE_PROCESSOR,
+                            "node",      node,
+                            "rectangle", rectangle,
+                            NULL);
 
-  if (rectangle)
+  if (node->operation                          &&
+      GEGL_IS_OPERATION_SINK (node->operation) &&
+      gegl_operation_sink_needs_full (node->operation))
     {
-      gegl_processor_set_rectangle (processor, rectangle);
-    }
-  else
-    {
-      GeglRectangle tmp = gegl_node_get_bounding_box (processor->input);
-      gegl_processor_set_rectangle (processor, &tmp);
-    }
+      GeglCache *cache;
 
-  if (node->operation &&
-      GEGL_IS_OPERATION_SINK (node->operation))
-    {
-      GeglCache     *cache;
-
-      if (!gegl_operation_sink_needs_full (node->operation))
-          return processor;
       cache = gegl_node_get_cache (processor->input);
 
       processor->context = gegl_node_add_context (node, cache);
@@ -269,123 +318,35 @@ gegl_node_new_processor (GeglNode            *node,
         GValue value = { 0, };
         g_value_init (&value, GEGL_TYPE_BUFFER);
         g_value_set_object (&value, cache);
-        gegl_node_context_set_property (processor->context, "input", &value);
+        gegl_operation_context_set_property (processor->context, "input", &value);
         g_value_unset (&value);
       }
 
-      gegl_node_context_set_result_rect (processor->context,
-                                         processor->rectangle.x,
-                                         processor->rectangle.y,
-                                         processor->rectangle.width,
-                                         processor->rectangle.height);
-      gegl_node_context_set_need_rect   (processor->context,
-                                         processor->rectangle.x,
-                                         processor->rectangle.y,
-                                         processor->rectangle.width,
-                                         processor->rectangle.height);
-
-
-    }
-  else
-    {
-      processor->context = NULL;
+      gegl_operation_context_set_result_rect (processor->context,
+                                              &processor->rectangle);
+      gegl_operation_context_set_need_rect   (processor->context,
+                                              &processor->rectangle);
     }
 
   return processor;
 }
 
-
-
 /* returns TRUE if there is more work */
-static gboolean render_rectangle_buffered (GeglProcessor *processor)
-{
-  GeglCache *cache    = gegl_node_get_cache (processor->input);
-  gint       max_area = processor->chunk_size;
-
-  if (processor->dirty_rectangles)
-    {
-      GeglRectangle *dr = processor->dirty_rectangles->data;
-      gint           pxsize;
-
-      g_object_get (cache, "px-size", &pxsize, NULL);
-
-      if (dr->height * dr->width > max_area && 1)
-        {
-          gint band_size;
-
-          if (dr->height > dr->width)
-            {
-              GeglRectangle *fragment;
-
-              band_size = dr->height / 2;
-
-              if (band_size < 1)
-                band_size = 1;
-
-              fragment = g_slice_dup (GeglRectangle, dr);
-
-              fragment->height = band_size;
-              dr->height      -= band_size;
-              dr->y           += band_size;
-
-              processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles, fragment);
-              return TRUE;
-            }
-          else
-            {
-              GeglRectangle *fragment;
-
-              band_size = dr->width / 2;
-
-              if (band_size < 1)
-                band_size = 1;
-
-              fragment = g_slice_dup (GeglRectangle, dr);
-
-              fragment->width = band_size;
-              dr->width      -= band_size;
-              dr->x          += band_size;
-
-              processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles, fragment);
-              return TRUE;
-            }
-        }
-
-      processor->dirty_rectangles = g_slist_remove (processor->dirty_rectangles, dr);
-
-      if (!dr->width || !dr->height)
-        {
-          g_slice_free (GeglRectangle, dr);
-          return TRUE;
-        }
-
-      if (gegl_region_rect_in (cache->valid_region, dr) !=
-          GEGL_OVERLAP_RECTANGLE_IN)
-        {
-          guchar *buf;
-
-          gegl_region_union_with_rect (cache->valid_region, dr);
-          buf = g_malloc (dr->width * dr->height * pxsize);
-          g_assert (buf);
-
-          gegl_node_blit (cache->node, 1.0, dr, cache->format, buf, GEGL_AUTO_ROWSTRIDE, GEGL_BLIT_DEFAULT);
-          gegl_buffer_set (GEGL_BUFFER (cache), dr, cache->format, buf, GEGL_AUTO_ROWSTRIDE);
-
-          gegl_cache_computed (cache, dr);
-
-          g_free (buf);
-        }
-
-      g_slice_free (GeglRectangle, dr);
-    }
-
-  return processor->dirty_rectangles != NULL;
-}
-
-/* returns TRUE if there is more work */
-static gboolean render_rectangle_unbuffered (GeglProcessor *processor)
+static gboolean
+render_rectangle (GeglProcessor *processor)
 {
+  gboolean   buffered;
   const gint max_area = processor->chunk_size;
+  GeglCache *cache    = NULL;
+  gint       pxsize;
+
+  buffered = !(GEGL_IS_OPERATION_SINK(processor->node->operation) &&
+               !gegl_operation_sink_needs_full (processor->node->operation));
+  if (buffered)
+    {
+      cache = gegl_node_get_cache (processor->input);
+      g_object_get (cache, "px-size", &pxsize, NULL);
+    }
 
   if (processor->dirty_rectangles)
     {
@@ -411,6 +372,7 @@ static gboolean render_rectangle_unbuffered (GeglProcessor *processor)
               dr->y           += band_size;
 
               processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles, fragment);
+
               return TRUE;
             }
           else
@@ -429,6 +391,7 @@ static gboolean render_rectangle_unbuffered (GeglProcessor *processor)
               dr->x          += band_size;
 
               processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles, fragment);
+
               return TRUE;
             }
         }
@@ -437,36 +400,58 @@ static gboolean render_rectangle_unbuffered (GeglProcessor *processor)
       if (!dr->width || !dr->height)
         {
           g_slice_free (GeglRectangle, dr);
+
           return TRUE;
         }
+	
+      if (buffered)
+        {
+          /* only do work if the rectangle is not completely inside the valid
+           * region of the cache
+           */
+          if (gegl_region_rect_in (cache->valid_region, dr) !=
+              GEGL_OVERLAP_RECTANGLE_IN)
+            {
+              guchar *buf;
 
-      gegl_node_blit (processor->node, 1.0, dr, NULL, NULL, GEGL_AUTO_ROWSTRIDE, GEGL_BLIT_DEFAULT);
-      gegl_region_union_with_rect (processor->valid_region, dr);
-      g_slice_free (GeglRectangle, dr);
+              gegl_region_union_with_rect (cache->valid_region, dr);
+              buf = g_malloc (dr->width * dr->height * pxsize);
+              g_assert (buf);
+
+              gegl_node_blit (cache->node, 1.0, dr, cache->format, buf,
+                              GEGL_AUTO_ROWSTRIDE, GEGL_BLIT_DEFAULT);
+
+
+              /* check that we haven't been recently */
+              gegl_buffer_set (GEGL_BUFFER (cache), dr, cache->format, buf,
+                               GEGL_AUTO_ROWSTRIDE);
+
+              gegl_cache_computed (cache, dr);
+
+              g_free (buf);
+            }
+        }
+      else
+        {
+           gegl_node_blit (processor->node, 1.0, dr, NULL, NULL,
+                           GEGL_AUTO_ROWSTRIDE, GEGL_BLIT_DEFAULT);
+           gegl_region_union_with_rect (processor->valid_region, dr);
+           g_slice_free (GeglRectangle, dr);
+        }
     }
 
   return processor->dirty_rectangles != NULL;
 }
 
 
-/* FIXME: merge duplicated code between the two different code paths
- */
-static gboolean render_rectangle (GeglProcessor *processor)
-{
-  if (GEGL_IS_OPERATION_SINK (processor->node->operation) &&
-      !gegl_operation_sink_needs_full (processor->node->operation))
-   {
-     return render_rectangle_unbuffered (processor);
-   }
-  return render_rectangle_buffered (processor);
-}
-
-static gint rect_area (GeglRectangle *rectangle)
+static gint
+rect_area (GeglRectangle *rectangle)
 {
   return rectangle->width * rectangle->height;
 }
 
-static gint region_area (GeglRegion *region)
+static gint
+region_area (GeglRegion *region)
 {
   GeglRectangle *rectangles;
   gint           n_rectangles;
@@ -484,8 +469,9 @@ static gint region_area (GeglRegion *region)
   return sum;
 }
 
-static gint area_left (GeglRegion    *area,
-                       GeglRectangle *rectangle)
+static gint
+area_left (GeglRegion    *area,
+           GeglRectangle *rectangle)
 {
   GeglRegion *region;
   gint        sum = 0;
@@ -510,14 +496,18 @@ static gdouble
 gegl_processor_progress (GeglProcessor *processor)
 {
   GeglRegion *valid_region;
-  gint valid;
-  gint wanted;
-  gdouble ret;
+  gint        valid;
+  gint        wanted;
+  gdouble     ret;
 
   if (processor->valid_region)
-    valid_region = processor->valid_region;
+    {
+      valid_region = processor->valid_region;
+    }
   else
-    valid_region = gegl_node_get_cache (processor->input)->valid_region;
+    {
+      valid_region = gegl_node_get_cache (processor->input)->valid_region;
+    }
 
   wanted = rect_area (&(processor->rectangle));
   valid  = wanted - area_left (valid_region, &(processor->rectangle));
@@ -527,13 +517,16 @@ gegl_processor_progress (GeglProcessor *processor)
         return 1.0;
       return 0.999;
     }
+
   ret = (double) valid / wanted;
-  g_warning ("%f", ret);
   if (ret>=1.0)
     {
       if (!gegl_processor_is_rendered (processor))
-        return 0.9999;
+        {
+          return 0.9999;
+        }
     }
+
   return ret;
 }
 
@@ -545,12 +538,17 @@ gegl_processor_render (GeglProcessor *processor,
   GeglRegion *valid_region;
 
   if (processor->valid_region)
-    valid_region = processor->valid_region;
+    {
+      valid_region = processor->valid_region;
+    }
   else
-    valid_region = gegl_node_get_cache (processor->input)->valid_region;
+    {
+      valid_region = gegl_node_get_cache (processor->input)->valid_region;
+    }
 
   {
     gboolean more_work = render_rectangle (processor);
+
     if (more_work == TRUE)
       {
         if (progress)
@@ -577,6 +575,7 @@ gegl_processor_render (GeglProcessor *processor,
               }
             wanted = 1;
           }
+
         return more_work;
       }
   }
@@ -603,6 +602,7 @@ gegl_processor_render (GeglProcessor *processor,
           processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles,
                                                          g_slice_dup (GeglRectangle, &roi));
         }
+
       g_free (rectangles);
 
       if (n_rectangles != 0)
@@ -612,6 +612,7 @@ gegl_processor_render (GeglProcessor *processor,
                                rect_area (rectangle));
           return TRUE;
         }
+
       return FALSE;
     }
   else if (!gegl_region_empty (processor->queued_region) &&
@@ -636,92 +637,18 @@ gegl_processor_render (GeglProcessor *processor,
           processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles,
                                                          g_slice_dup (GeglRectangle, &roi));
         }
+
       g_free (rectangles);
     }
+
   if (progress)
-    *progress = 0.69;
+    {
+      *progress = 0.69;
+    }
 
   return !gegl_processor_is_rendered (processor);
 }
 
-
-/*#define ENABLE_THREADING*/
-/*#ifdef ENABLE_THREADING*/
-#if 0
-
-gpointer render_thread (gpointer data)
-{
-  GeglProcessor *processor = data;
-
-  while (gegl_processor_render (processor, &processor->rectangle, &processor->progress));
-  processor->thread_done = TRUE;
-  return NULL;
-}
-
-gboolean
-gegl_processor_work (GeglProcessor *processor,
-                     gdouble       *progress)
-{
-  gboolean   more_work = FALSE;
-  GeglCache *cache;
-
-  if (!processor->thread)
-    {
-      processor->thread = g_thread_create (render_thread,
-                                           processor,
-                                           FALSE,
-                                           NULL);
-      processor->thread_done = FALSE;
-      if (progress)
-        *progress = processor->progress;
-      more_work = !processor->thread_done;
-    }
-  else
-    {
-      if (progress)
-        *progress = processor->progress;
-      if (processor->thread_done)
-        {
-          processor->thread = NULL;
-        }
-      more_work = !processor->thread_done;
-    }
-
-  /*more_work = gegl_processor_render (processor, &processor->rectangle, progress);*/
-
-  if (more_work)
-    {
-      return TRUE;
-    }
-
-  if (GEGL_IS_OPERATION_SINK (processor->node->operation) &&
-      !gegl_operation_sink_needs_full (processor->node->operation))
-    {
-      if (progress)
-        *progress = 1.0;
-      return FALSE;
-    }
-
-  cache = gegl_node_get_cache (processor->input);
-
-  if (processor->context)
-    {
-      gegl_operation_process (processor->node->operation, cache, "foo");
-      gegl_node_remove_context (processor->node, cache);
-      processor->context = NULL;
-      if (progress)
-        *progress = 1.0;
-      return TRUE;
-    }
-
-  if (progress)
-    *progress = 1.0;
-
-  return FALSE;
-}
-
-#else
-
 gboolean
 gegl_processor_work (GeglProcessor *processor,
                      gdouble       *progress)
@@ -746,16 +673,20 @@ gegl_processor_work (GeglProcessor *processor,
       gegl_node_remove_context (processor->node, cache);
       processor->context = NULL;
       if (progress)
-        *progress = 1.0;
+        {
+          *progress = 1.0;
+        }
+
       return TRUE;
     }
 
   if (progress)
-    *progress = 1.0;
+    {
+      *progress = 1.0;
+    }
 
   return FALSE;
 }
-#endif
 
 void
 gegl_processor_destroy (GeglProcessor *processor)
