@@ -15,9 +15,15 @@
  *
  * Copyright 2006 Øyvind Kolås <pippin@gimp.org>
  */
+
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
+
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_double (dampness, "Dampness", 0.0, 1.0, 0.95, "The value represents the contribution of the past to the new frame.")
+gegl_chant_double (dampness, _("Dampness"), 0.0, 1.0, 0.95,
+    _("The value represents the contribution of the past to the new frame."))
 
 #else
 
@@ -115,7 +121,7 @@ finalize (GObject *object)
       o->chant_data = NULL;
     }
 
-  G_OBJECT_CLASS (g_type_class_peek_parent (G_OBJECT_GET_CLASS (object)))->finalize (object);
+  G_OBJECT_CLASS (gegl_chant_parent_class)->finalize (object);
 }
 
 
@@ -135,7 +141,7 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   operation_class->name        = "mblur";
   operation_class->categories  = "blur:video";
-  operation_class->description = "Accumulating motion blur";
+  operation_class->description = _("Accumulating motion blur");
 }
 
 #endif
