@@ -17,9 +17,14 @@
  * Copyright 2006 Geert Jordaens <geert.jordaens@telenet.be>
  */
 
+
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
+
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_string (values, "Values", "", "list of <number>s")
+gegl_chant_string (values, _("Values"), "", _("list of <number>s"))
 
 #else
 
@@ -85,7 +90,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->name        = "svg-luminancetoalpha";
   operation_class->categories  = "compositors:svgfilter";
   operation_class->description =
-        "SVG color matrix operation svg_luminancetoalpha";
+        _("SVG color matrix operation svg_luminancetoalpha");
 }
 
 #endif
