@@ -16,10 +16,14 @@
  * Copyright 2006 Øyvind Kolås <pippin@gimp.org>
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
+
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_string (ref, "Reference", "ID",
-                   "The reference ID used as input (for use in XML).")
+gegl_chant_string (ref, _("Reference"), "ID",
+                   _("The reference ID used as input (for use in XML)."))
 
 #else
 
@@ -66,7 +70,7 @@ get_bounding_box (GeglOperation *operation)
 
 static gboolean
 process (GeglOperation       *operation,
-         GeglNodeContext     *context,
+         GeglOperationContext     *context,
          const gchar         *output_prop,
          const GeglRectangle *result)
 {
@@ -78,13 +82,13 @@ process (GeglOperation       *operation,
       return FALSE;
     }
 
-  input  = gegl_node_context_get_source (context, "input");
+  input  = gegl_operation_context_get_source (context, "input");
   if (!input)
     {
       g_warning ("clone received NULL input");
       return FALSE;
     }
-  gegl_node_context_set_object (context, "output", G_OBJECT (input));
+  gegl_operation_context_set_object (context, "output", G_OBJECT (input));
   return TRUE;
 }
 
@@ -101,7 +105,7 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   operation_class->name        = "clone";
   operation_class->categories  = "core";
-  operation_class->description = "Clone a buffer";
+  operation_class->description = _("Clone a buffer");
 
   operation_class->no_cache = TRUE;
 }
