@@ -16,12 +16,16 @@
  * Copyright 2006 Øyvind Kolås
  */
 
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
+
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_double (x,      "X",      -G_MAXFLOAT, G_MAXFLOAT,  0.0, "X")
-gegl_chant_double (y,      "Y",      -G_MAXFLOAT, G_MAXFLOAT,  0.0, "Y")
-gegl_chant_double (width,  "Width",  -G_MAXFLOAT, G_MAXFLOAT, 10.0, "Width")
-gegl_chant_double (height, "Height", -G_MAXFLOAT, G_MAXFLOAT, 10.0, "Height")
+gegl_chant_double (x,      _("X"),      -G_MAXFLOAT, G_MAXFLOAT,  0.0, _("X"))
+gegl_chant_double (y,      _("Y"),      -G_MAXFLOAT, G_MAXFLOAT,  0.0, _("Y"))
+gegl_chant_double (width,  _("Width"),  -G_MAXFLOAT, G_MAXFLOAT, 10.0, _("Width"))
+gegl_chant_double (height, _("Height"), -G_MAXFLOAT, G_MAXFLOAT, 10.0, _("Height"))
 
 #else
 
@@ -87,12 +91,15 @@ get_required_for_output (GeglOperation       *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *roi)
 {
-  return *roi;
+  GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
+  GeglRectangle result = {o->x, o->y, o->width, o->height};
+  gegl_rectangle_intersect (&result, &result, roi);
+  return result;
 }
 
 static gboolean
 process (GeglOperation       *operation,
-         GeglNodeContext     *context,
+         GeglOperationContext     *context,
          const gchar         *output_prop,
          const GeglRectangle *result)
 {
@@ -107,14 +114,14 @@ process (GeglOperation       *operation,
       return FALSE;
     }
 
-  input  = gegl_node_context_get_source (context, "input");
+  input  = gegl_operation_context_get_source (context, "input");
 
   if (input != NULL)
     {
       GeglBuffer *output;
 
       output = gegl_buffer_create_sub_buffer (input, &extent);
-      gegl_node_context_set_object (context, "output", G_OBJECT (output));
+      gegl_operation_context_set_object (context, "output", G_OBJECT (output));
       g_object_unref (input);
       success = TRUE;
     }
@@ -145,7 +152,7 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   operation_class->name        = "crop";
   operation_class->categories  = "core";
-  operation_class->description = "Crop a buffer";
+  operation_class->description = _("Crop a buffer");
 
   operation_class->no_cache = TRUE;
 }
