@@ -15,73 +15,24 @@
  *
  * Copyright 2006 Øyvind Kolås <pippin@gimp.org>
  */
-#if GEGL_CHANT_PROPERTIES
- 
-gegl_chant_double (radius, 0.0, 200.0, 4.0,
-  "Radius of square pixel region, (width and height will be radius*2+1.")
+
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
+
+#ifdef GEGL_CHANT_PROPERTIES
+
+gegl_chant_double (radius, _("Radius"), 0.0, 200.0, 4.0,
+  _("Radius of square pixel region (width and height will be radius*2+1)"))
 
 #else
 
-#define GEGL_CHANT_NAME            box_min
-#define GEGL_CHANT_SELF            "box-min.c"
-#define GEGL_CHANT_DESCRIPTION     "Sets the target pixel to the value of the minimum value in a box surrounding the pixel."
-#define GEGL_CHANT_CATEGORIES      "misc"
-
-#define GEGL_CHANT_AREA_FILTER
+#define GEGL_CHANT_TYPE_AREA_FILTER
+#define GEGL_CHANT_C_FILE       "box-min.c"
 
 #include "gegl-chant.h"
-
-static void hor_min (GeglBuffer *src,
-                     GeglBuffer *dst,
-                     gint        radius);
-
-static void ver_min (GeglBuffer *src,
-                     GeglBuffer *dst,
-                     gint        radius);
-
 #include <stdio.h>
-
-static gboolean
-process (GeglOperation *operation,
-         gpointer       context_id)
-{
-  GeglOperationFilter *filter;
-  GeglChantOperation  *self;
-  GeglBuffer          *input;
-  GeglBuffer          *output;
-
-  filter = GEGL_OPERATION_FILTER (operation);
-  self   = GEGL_CHANT_OPERATION (operation);
-
-
-  input = GEGL_BUFFER (gegl_operation_get_data (operation, context_id, "input"));
-    {
-      GeglRectangle   *result = gegl_operation_result_rect (operation, context_id);
-      GeglBuffer      *temp_in;
-      GeglBuffer      *temp;
-      GeglRectangle compute  = gegl_operation_compute_input_request (operation, "inputt", gegl_operation_need_rect (operation, context_id));
-
-
-      temp_in = gegl_buffer_create_sub_buffer (input, &compute);
-      temp   = gegl_buffer_new (&compute, babl_format ("RGBA float"));
-
-      output = gegl_buffer_new (&compute, babl_format ("RGBA float"));
-
-
-      hor_min (temp_in, temp,  self->radius);
-      ver_min (temp, output, self->radius);
-      g_object_unref (temp);
-      g_object_unref (temp_in);
-      
-
-      {
-        GeglBuffer *cropped = gegl_buffer_create_sub_buffer (output, result);
-        gegl_operation_set_data (operation, context_id, "output", G_OBJECT (cropped));
-        g_object_unref (output);
-      }
-    }
-  return  TRUE;
-}
+#include <math.h>
 
 static inline gfloat
 get_min_component (gfloat *buf,
@@ -127,8 +78,8 @@ hor_min (GeglBuffer *src,
   gfloat *src_buf;
   gfloat *dst_buf;
 
-  src_buf = g_malloc0 (gegl_buffer_get_pixel_count (src) * 4 * 4);
-  dst_buf = g_malloc0 (gegl_buffer_get_pixel_count (dst) * 4 * 4);
+  src_buf = g_new0 (gfloat, gegl_buffer_get_pixel_count (src) * 4);
+  dst_buf = g_new0 (gfloat, gegl_buffer_get_pixel_count (dst) * 4);
 
   gegl_buffer_get (src, 1.0, NULL, babl_format ("RGBA float"), src_buf, GEGL_AUTO_ROWSTRIDE);
 
@@ -149,7 +100,8 @@ hor_min (GeglBuffer *src,
                                i);
       }
 
-  gegl_buffer_set (dst, NULL, babl_format ("RGBA float"), dst_buf);
+  gegl_buffer_set (dst, NULL, babl_format ("RGBA float"), dst_buf,
+                   GEGL_AUTO_ROWSTRIDE);
   g_free (src_buf);
   g_free (dst_buf);
 }
@@ -165,9 +117,9 @@ ver_min (GeglBuffer *src,
   gfloat *src_buf;
   gfloat *dst_buf;
 
-  src_buf = g_malloc0 (gegl_buffer_get_pixel_count (src) * 4 * 4);
-  dst_buf = g_malloc0 (gegl_buffer_get_pixel_count (dst) * 4 * 4);
-  
+  src_buf = g_new0 (gfloat, gegl_buffer_get_pixel_count (src) * 4);
+  dst_buf = g_new0 (gfloat, gegl_buffer_get_pixel_count (dst) * 4);
+
   gegl_buffer_get (src, 1.0, NULL, babl_format ("RGBA float"), src_buf, GEGL_AUTO_ROWSTRIDE);
 
   offset=0;
@@ -188,19 +140,59 @@ ver_min (GeglBuffer *src,
                               c);
       }
 
-  gegl_buffer_set (dst, NULL, babl_format ("RGBA float"), dst_buf);
+  gegl_buffer_set (dst, NULL, babl_format ("RGBA float"), dst_buf,
+                   GEGL_AUTO_ROWSTRIDE);
   g_free (src_buf);
   g_free (dst_buf);
 }
 
-#include <math.h>
-
-static void tickle (GeglOperation *operation)
+static void prepare (GeglOperation *operation)
 {
   GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
-  GeglChantOperation      *filter = GEGL_CHANT_OPERATION (operation);
-  area->left = area->right = area->top = area->bottom =
-      ceil (filter->radius);
+  area->left  =
+  area->right =
+  area->top   =
+  area->bottom = GEGL_CHANT_PROPERTIES (operation)->radius;
+  gegl_operation_set_format (operation, "output", babl_format ("RGBA float"));
+}
+
+static gboolean
+process (GeglOperation       *operation,
+         GeglBuffer          *input,
+         GeglBuffer          *output,
+         const GeglRectangle *result)
+{
+  GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
+  GeglBuffer *temp;
+
+  temp = gegl_buffer_new (gegl_buffer_get_extent (input),
+                          babl_format ("RGBA float"));
+
+  hor_min (input, temp,  o->radius);
+  ver_min (temp, output, o->radius);
+
+  g_object_unref (temp);
+
+  return  TRUE;
+}
+
+
+static void
+gegl_chant_class_init (GeglChantClass *klass)
+{
+  GeglOperationClass       *operation_class;
+  GeglOperationFilterClass *filter_class;
+
+  operation_class = GEGL_OPERATION_CLASS (klass);
+  filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
+
+  filter_class->process = process;
+  operation_class->prepare = prepare;
+
+  operation_class->name        = "box-min";
+  operation_class->categories  = "misc";
+  operation_class->description =
+        _("Sets the target pixel to the value of the minimum value in a box surrounding the pixel.");
 }
 
 #endif
