@@ -17,70 +17,66 @@
  *           2007 Øyvind Kolås <oeyvindk@hig.no>
  */
 
-#if GEGL_CHANT_PROPERTIES 
-#define MAX_SAMPLES 20000 /* adapted to max level of radius */
 
-gegl_chant_double (radius, 0.0, 70.0, 4.0,
-  "Radius of square pixel region, (width and height will be radius*2+1.")
-gegl_chant_double (percentile, 0.0, 100.0, 50, "The percentile to compute, defaults to 50, which is a median filter.")
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
+
+#ifdef GEGL_CHANT_PROPERTIES
+
+gegl_chant_double (radius, _("Radius"), 0.0, 70.0, 4.0,
+  _("Radius of square pixel region (width and height will be radius*2+1)"))
+gegl_chant_double (percentile, _("Percentile"), 0.0, 100.0, 50,
+  _("The percentile to compute, defaults to 50, which is a median filter."))
 
 #else
 
-#define GEGL_CHANT_NAME            box_percentile
-#define GEGL_CHANT_SELF            "box-percentile.c"
-#define GEGL_CHANT_DESCRIPTION     "Sets the target pixel to the color corresponding to a given percentile when colors are sorted by luminance."
-#define GEGL_CHANT_CATEGORIES      "misc"
+#define MAX_SAMPLES 20000 /* adapted to max level of radius */
 
-#define GEGL_CHANT_AREA_FILTER
+#define GEGL_CHANT_TYPE_AREA_FILTER
+#define GEGL_CHANT_C_FILE       "box-percentile.c"
 
 #include "gegl-chant.h"
+#include <stdio.h>
+#include <math.h>
 
 static void median (GeglBuffer *src,
                     GeglBuffer *dst,
                     gint        radius,
                     gdouble     rank);
 
-#include <stdio.h>
+
+static void prepare (GeglOperation *operation)
+{
+  GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
+  GeglChantO              *o = GEGL_CHANT_PROPERTIES (operation);
+  area->left = area->right = area->top = area->bottom = ceil (o->radius);
+
+  gegl_operation_set_format (operation, "output", babl_format ("RGBA float"));
+}
 
 static gboolean
-process (GeglOperation *operation,
-         gpointer       context_id)
+process (GeglOperation       *operation,
+         GeglBuffer          *input,
+         GeglBuffer          *output,
+         const GeglRectangle *result)
 {
-  GeglOperationFilter *filter;
-  GeglChantOperation  *self;
-  GeglBuffer          *input;
-  GeglBuffer          *output;
+  GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
+  GeglBuffer   *temp_in;
+  GeglRectangle compute = gegl_operation_get_required_for_output (operation, "input", result);
 
-  filter = GEGL_OPERATION_FILTER (operation);
-  self   = GEGL_CHANT_OPERATION (operation);
-
-
-  input = GEGL_BUFFER (gegl_operation_get_data (operation, context_id, "input"));
+  if (o->radius < 1.0)
     {
-      GeglRectangle   *result = gegl_operation_result_rect (operation, context_id);
-      GeglBuffer      *temp_in;
-      GeglRectangle compute  = gegl_operation_compute_input_request (operation, "inputt", gegl_operation_need_rect (operation, context_id));
-
-      if (self->radius < 1.0)
-        {
-          output = g_object_ref (input);
-        }
-      else
-        {
-
-          temp_in = gegl_buffer_create_sub_buffer (input, &compute);
-          output = gegl_buffer_new (&compute, babl_format ("RGBA float"));
-
-          median (temp_in, output, self->radius, self->percentile / 100.0);
-          g_object_unref (temp_in);
-        }
-
-      {
-        GeglBuffer *cropped = gegl_buffer_create_sub_buffer (output, result);
-        gegl_operation_set_data (operation, context_id, "output", G_OBJECT (cropped));
-        g_object_unref (output);
-      }
+      output = g_object_ref (input);
     }
+  else
+    {
+      temp_in = gegl_buffer_create_sub_buffer (input, &compute);
+
+      median (temp_in, output, o->radius, o->percentile / 100.0);
+      g_object_unref (temp_in);
+    }
+
   return  TRUE;
 }
 
@@ -184,7 +180,7 @@ median (GeglBuffer *src,
       {
         gint u,v;
         gfloat *median_pix;
-        
+
         list_clear (&list);
 
         for (v=y-radius;v<=y+radius;v++)
@@ -206,19 +202,30 @@ median (GeglBuffer *src,
           dst_buf[offset*4+u] = median_pix[u];
         offset++;
       }
-  gegl_buffer_set (dst, NULL, babl_format ("RGBA float"), dst_buf);
+  gegl_buffer_set (dst, NULL, babl_format ("RGBA float"), dst_buf,
+                   GEGL_AUTO_ROWSTRIDE);
   g_free (src_buf);
   g_free (dst_buf);
 }
 
-#include <math.h>
 
-static void tickle (GeglOperation *operation)
+static void
+gegl_chant_class_init (GeglChantClass *klass)
 {
-  GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
-  GeglChantOperation      *filter = GEGL_CHANT_OPERATION (operation);
-  area->left = area->right = area->top = area->bottom =
-      ceil (filter->radius);
+  GeglOperationClass       *operation_class;
+  GeglOperationFilterClass *filter_class;
+
+  operation_class = GEGL_OPERATION_CLASS (klass);
+  filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
+
+  filter_class->process = process;
+  operation_class->prepare = prepare;
+
+  operation_class->name        = "box-percentile";
+  operation_class->categories  = "misc";
+  operation_class->description =
+        _("Sets the target pixel to the color corresponding to a given percentile "
+          "when colors are sorted by luminance.");
 }
 
 #endif
