@@ -15,10 +15,15 @@
  *
  * Copyright 2006 Øyvind Kolås <pippin@gimp.org>
  */
+
+#include "config.h"
+#include <glib/gi18n-lib.h>
+
+
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_int (pattern, "Bayer pattern", 0, 3, 0,
-                "Bayer pattern used, 0 seems to work for some nikon files, 2 for some Fuji files.")
+gegl_chant_int (pattern, _("Bayer pattern"), 0, 3, 0,
+                _("Bayer pattern used, 0 seems to work for some nikon files, 2 for some Fuji files."))
 
 #else
 
@@ -145,6 +150,6 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->name        = "demosaic-simple";
   operation_class->categories  = "blur";
   operation_class->description =
-        "Performs a naive grayscale2color demosaicing of an image, no interpolation.";
+        _("Performs a naive grayscale2color demosaicing of an image, no interpolation.");
 }
 #endif
