@@ -260,7 +260,7 @@ CSS="div.function{
         display: block;
         font-style: italic;
         color: #22F;
-        width: 8em;
+        width: 10em;
         float: left;
   }
   div.arg_name{
@@ -507,7 +507,7 @@ file.puts "<div id='toc'>
       <ul>
         <li><a href='index.html' style='padding-top: 0.5em;'>GEGL</a></li>
         <li><a href='index.html#Documentation' style='padding-top: 0.5em;'>Documentation</a></li>
-        <li><a href='index.html#Glossary'>&nbsp;&nbsp;Glossary</a></li>
+        <li><a href='index.html#_glossary'>&nbsp;&nbsp;Glossary</a></li>
         <li><a href='operations.html'>&nbsp;&nbsp;Operations</a></li>
 
 "
@@ -538,6 +538,7 @@ File.open("gegl.devhelp", "w") {|file|
          file.puts "<sub name='#{element.name}' link='api.html\##{element.name.gsub(' ','_')}'/>"
        end
     }
+    file.puts "<sub name='Operations' link='operations.html'/>"
     file.puts "</chapters>"
     file.puts "<functions>"
 
@@ -548,6 +549,15 @@ File.open("gegl.devhelp", "w") {|file|
        if element.is_a? Section and !element.name.empty? and element.name=~ /^Gegl/
          file.puts "<function name='#{element.name}' link='api.html\##{element.name.gsub(' ','_')}'/>"
        end
+
+
+    }
+
+    IO.foreach("operations.html"){ |line|
+        if line =~ /^<li><a href='#op_.*'>.*<\/a><\/li>/
+            opname=line.gsub(/.*op_/,'').gsub(/'.*/,'').strip
+            file.puts "<function name='gegl-#{opname}' link='operations.html#op_#{opname}'/>"
+        end
     }
 
     file.puts "</functions>"
